
""" ``comp`` module.
"""

import sys


PY3 = sys.version_info[0] >= 3

if PY3:  # pragma: nocover
    basestring = (str, bytes)

    def ntob(n, encoding):
        """ Converts native string to bytes
        """
        return n.encode(encoding)

    #import collections
    #callable = lambda obj: isinstance(obj, collections.Callable)
    callable = lambda obj: any(
        "__call__" in klass.__dict__ for klass in type(obj).__mro__)
else:  # pragma: nocover
    basestring = basestring

    def ntob(n, encoding):
        """ Converts native string to bytes
        """
        return n

    callable = callable


if PY3:  # pragma: nocover
    iteritems = lambda d: d.items()
    copyitems = lambda d: list(d.items())
else:  # pragma: nocover
    iteritems = lambda d: d.iteritems()
    copyitems = lambda d: d.items()



#!/usr/bin/env python

import os

try:
    from setuptools import setup
except:
    from distutils.core import setup

README = open(os.path.join(os.path.dirname(__file__), 'README')).read()

setup(
    name='wheezy.routing',
    version='0.1',
    description='A lightweight path routing library',
    long_description=README,
    url='https://bitbucket.org/akorn/wheezy.routing',

    author='Andriy Kornatskyy',
    author_email='andriy.kornatskyy at live.com',

    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.4',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Internet :: WWW/HTTP :: WSGI',
        'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    keywords='routing path url patterns match web mapping',
    packages=['wheezy', 'wheezy.routing'],
    package_dir={'': 'src'},
    namespace_packages=['wheezy'],

    zip_safe=False,
    install_requires=[
    ],
    extras_require={
        'dev': [
            'wsgiref',
            'coverage',
            'nose',
            'pytest',
            'pytest-pep8',
            'pytest-cov',
            'mocker'
        ]
    },

    platforms='any'
)




""" ``config`` module.
"""

from wheezy.routing.builders import try_build_plain_route
from wheezy.routing.builders import try_build_curly_route
from wheezy.routing.builders import try_build_regex_route

from wheezy.routing.curly import patterns as curly_patterns
from wheezy.routing.curly import default_pattern as curly_default_pattern

route_builders = [
    try_build_plain_route,
    try_build_curly_route,
    try_build_regex_route
]
